# Examples

## Python

```toml
{! ../example_checkers/python.toml!}
```

## Ruff

```toml
{! ../example_checkers/ruff.toml!}
```

## Black

```toml
{! ../example_checkers/black.toml!}
```

## Mypy

```toml
{! ../example_checkers/mypy.toml!}
```

## Bashrc

```toml
{! ../example_checkers/bash.toml!}
```

